@@ -1,26 +1,23 @@
-import sys
-import json
 import importlib
-import argparse
+import json
 import os
-import base64
 import re
 import typing as t
-import typing_extensions as te
 import uuid
 
-from .types import FileCategory, File, ReadResult
-
-from .__util_storage import Storage
+from .__util_command import Command
 from .__util_datalake import Datalake
 from .__util_es_datalake import es_datalake_search_eql, es_hit_to_file_pointer
+from .__util_fileinfo import Fileinfo
+from .__util_ids import create_ids_util
 from .__util_log import Log
 from .__util_merge import merge_arrays, merge_objects
 from .__util_metadata import FIELDS
-from .__util_ids import create_ids_util
-from .__util_command import Command
-from .__util_fileinfo import Fileinfo
-from .__util_validation import validate_file_meta, validate_file_tags, validate_file_labels
+from .__util_storage import Storage
+from .__util_validation import (validate_file_labels, validate_file_meta,
+                                validate_file_tags)
+from .type_hints import Label
+from .types import File, FileCategory, ReadResult
 
 COMPLETED = 'completed'
 FAILED = 'failed'
@@ -153,7 +150,7 @@ class Context:
         custom_metadata: t.Mapping[str, str] = {},
         custom_tags: t.Iterable[str] = [],
         source_type: t.Optional[str] = None,
-        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]] = []
+        labels: t.Iterable[Label] = []
     ) -> File:
         """Writes an output file to the data lake
         """
@@ -208,7 +205,7 @@ class Context:
         custom_tags: t.Iterable[str] = [],
         source_type: t.Optional[str] = None,
         file_category: t.Optional[str] = 'IDS',
-        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]] = []
+        labels: t.Iterable[Label] = []
     ) -> File:
         """Similar to write_file, but for IDS
         """
@@ -322,7 +319,7 @@ class Context:
     def add_labels(
         self, 
         file: File, 
-        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]],
+        labels: t.Iterable[t.Dict[str, t.Any]],
         no_propagate: bool = False
     ):
         validate_file_labels(labels)
@@ -344,7 +341,7 @@ class Context:
         file: File, 
         custom_meta: t.Mapping[str, str] = {},
         custom_tags: t.Iterable[str] = [],
-        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]] = []
+        labels: t.Iterable[Label] = []
     ) -> File:
 
         if not custom_meta and not custom_tags:
