@@ -367,7 +367,9 @@ class Datalake:
         current_meta = lowerMetadataKeys(head.get('Metadata'))
 
         if not FIELDS['FILE_ID'] in current_meta:
-            raise Exception('no FILE_ID in meta!')
+            raise KeyError(f"{FIELDS['FILE_ID']} not found in meta!")
+
+        file_id = current_meta.get(FIELDS['FILE_ID'])
 
         if (not custom_meta) and (not custom_tags):
             print({'level': 'debug', 'message': 'no action taken because no metadata or tags provided'})
@@ -400,7 +402,7 @@ class Datalake:
         if len(custom_meta_str) + len(custom_tags_str) >= 1024 * 1.5:
             raise Exception('Metadata and tags length larger than 1.5KB')
 
-        file_id = options.get('new_file_id', str(uuid4()))
+        new_file_id = options.get('new_file_id', str(uuid4()))
 
         pipelineConfig = context.get('pipelineConfig', {})
 
@@ -421,10 +423,17 @@ class Datalake:
                 FIELDS['INTEGRATION_TYPE']: 'datapipeline',
                 FIELDS['VERSION']: '2',
 
-                FIELDS['FILE_ID']: file_id,
+                FIELDS['FILE_ID']: new_file_id,
                 FIELDS['CUSTOM_METADATA']: custom_meta_str,
                 FIELDS['CUSTOM_TAGS']: custom_tags_str,
 
+                # Indicate that the content of the new file comes from previous file
+                FIELDS['CONTENT_CREATED_FROM_FILE_ID']: file_id,
+
+                # Explicitly tell the TDP that this file will not inherit labels
+                # from the source or pipeline input file (RAW FILE ID)
+                FIELDS['DO_NOT_INHERIT_LABELS']: 'true',
+
                 # from pipeline context
                 FIELDS['INTEGRATION_ID']: getOrEmptyString(context, 'pipelineId'),
                 FIELDS['INTEGRATION_NAME']: getOrEmptyString(pipelineConfig, 'pipelineName'),
@@ -472,7 +481,7 @@ class Datalake:
             'type': 's3file',
             'bucket': bucket,
             'fileKey': file_key,
-            'fileId': file_id,
+            'fileId': new_file_id,
             'version': updated_version
         }
 
