@@ -1,8 +1,11 @@
 import re
 
+from typing import Iterable, Optional
+
+from ts_sdk.task.type_hints import Label
+
 # Please keep these regex is sync with:
 # https://github.com/tetrascience/ts-sdk-python/blob/main/ts_sdk/task/__util_validation.py
-
 meta_name_reg = re.compile(r'^[0-9a-zA-Z-_+ ]+$')
 meta_value_reg = re.compile(r'^[0-9a-zA-Z-_+.,/ ]+$')
 tag_reg = re.compile(r'^[0-9a-zA-Z-_+./ ]+$')
@@ -32,18 +35,24 @@ def validate_file_tags(tags):
             raise ValueError(f'Invalid tag {t}! Expected pattern: {tag_reg.pattern}')
     return True
 
-def validate_file_labels(labels):
+
+def validate_file_labels(labels: Optional[Iterable[Label]]) -> bool:
     if labels is None:
         return True
-    for l in labels:
-        n = l.get('name')
-        v = str(l.get('value'))
-        if not label_name_reg.match(n):
-            raise ValueError(f'Invalid label name {n}! Expected pattern: {label_name_reg.pattern}')
-        if not label_value_reg.match(v):
-            raise ValueError(f'Invalid label value {v}! Expected pattern: {meta_value_reg.pattern}')
-        validate_string_is_trimmed(n)
-        validate_string_is_trimmed(v)
+    for label in labels:
+        if "name" not in label:
+            raise ValueError('Label is missing the "name" key.')
+        if "value" not in label:
+            raise ValueError('Label is missing "value" key.')
+
+        label_name = label["name"]
+        label_value = label["value"]
+        if label_name_reg.match(str(label_name)) is None:
+            raise ValueError(f'Invalid label name "{label_name}"! Expected pattern: "{label_name_reg.pattern}"')
+        if label_value_reg.match(str(label_value)) is None:
+            raise ValueError(f'Invalid label value "{label_value}"! Expected pattern: "{label_value_reg.pattern}"')
+        validate_string_is_trimmed(label_name)
+        validate_string_is_trimmed(label_value)
     return True
 
 def validate_string_is_trimmed(s):
